@@ -76,7 +76,7 @@ class PycURLLibrary():
 #        Note that this is the negated option name documented. You can thus use --buffer to enforce the buffering. 
 #        """
         
-    def insecure(self):
+    def insecure_ssl(self):
         """(SSL) This option explicitly allows curl to perform "insecure" SSL connections and transfers.
         
         All SSL connections are attempted to be made secure by using the CA certificate bundle installed by default. 
@@ -166,23 +166,23 @@ class PycURLLibrary():
         
         Equivalent for <--capath> argument with curl
         """
-        self._url.get_context().set_capath(str(cacertDirectory))
+        self._url.get_context().set_capath(cacertDirectory)
         
-    def cert(self, cert):
+    def client_certificate_file(self, cert):
         """(SSL) Tells curl to use the specified client certificate file when getting a file with HTTPS, 
         FTPS or another SSL-based protocol. The certificate must be in PEM format
 
         Equivalent for <--cert> argument with curl
         """
-        self._url.get_context().set_cert(str(cert))
+        self._url.get_context().set_client_certificate_file(cert)
         
-    def key(self, key):
+    def private_key_file(self, key):
         """(SSL/SSH) Private key file name. 
         Allows you to provide your private key in this separate file. 
 
         Equivalent for <--key> argument with curl
         """
-        self._url.get_context().set_key(str(key))
+        self._url.get_context().set_private_key_file(key)
         
     def perform(self):
         """Perform curl perform.
