@@ -120,10 +120,12 @@ class Url(object):
                 # No need to break here, it'll stop anyway
         
         if self._insecure:
-            c.setopt(pycurl.SSL_VERIFYPEER, False)
+            self._logger.info("Insecure SSL enabled")
+            c.setopt(pycurl.SSL_VERIFYHOST, 0)
+            c.setopt(pycurl.SSL_VERIFYPEER, 0)
            
-        if self.get_context().get_cert() is not None:
-            cert = self.get_context().get_cert();
+        if self.get_context().get_client_certificate_file() is not None:
+            cert = self.get_context().get_client_certificate_file();
             self._logger.info("Client Certificate File %s" % (cert))
             try:
                 c.setopt(pycurl.SSLCERT, cert)
@@ -140,8 +142,8 @@ class Url(object):
                 self._logger.warn("Wrong setopt CAPATH value %s" % (capath))
                 raise TypeError(t)
             
-        if self.get_context().get_key() is not None:
-            privateKey = self.get_context().get_key()
+        if self.get_context().get_private_key_file() is not None:
+            privateKey = self.get_context().get_private_key_file()
             self._logger.info("Private Key File %s" % (privateKey))
             try:
                 c.setopt(pycurl.SSLKEY, privateKey)
@@ -149,7 +151,6 @@ class Url(object):
                 self._logger.warn("Wrong setopt SSLKEY value %s" % (privateKey))
                 raise TypeError(t)
             
-        self._logger.info("URL %s" % (self.get_context().get_url()))
         try:
             c.setopt(pycurl.URL, self.get_context().get_url())
         except TypeError, t:
@@ -199,6 +200,7 @@ class Url(object):
         
         self._logger.info(headers)
         if headers:
+            self._logger.info("Headers %s" % (headers))
             try:
                 c.setopt(pycurl.HTTPHEADER, headers)
             except TypeError, t:
